@@ -82,7 +82,6 @@ class InstallState:
         self.keep_outdated = False
         self.skip_lock = False
         self.ignore_pipfile = False
-        self.sequential = False
         self.code = False
         self.requirementstxt = None
         self.deploy = False
@@ -128,29 +127,11 @@ def editable_option(f):
         expose_value=False,
         multiple=True,
         callback=callback,
-        type=click_types.STRING,
+        type=click_types.Path(file_okay=False),
         help="An editable Python package URL or path, often to a VCS repository.",
     )(f)
 
 
-def sequential_option(f):
-    def callback(ctx, param, value):
-        state = ctx.ensure_object(State)
-        state.installstate.sequential = value
-        return value
-
-    return option(
-        "--sequential",
-        is_flag=True,
-        default=False,
-        expose_value=False,
-        help="Install dependencies one-at-a-time, instead of concurrently.",
-        callback=callback,
-        type=click_types.BOOL,
-        show_envvar=True,
-    )(f)
-
-
 def skip_lock_option(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
@@ -479,7 +460,7 @@ def requirementstxt_option(f):
         expose_value=False,
         help="Import a requirements.txt file.",
         callback=callback,
-        type=click_types.STRING,
+        type=click_types.Path(dir_okay=False),
     )(f)
 
 
@@ -583,7 +564,6 @@ def lock_options(f):
 def sync_options(f):
     f = install_base_options(f)
     f = install_dev_option(f)
-    f = sequential_option(f)
     return f
 
 
